=========
Constants
=========


.. data:: netsgiro.NETS_ID

    Nets' data transmitter/recipient ID

    >>> import netsgiro
    >>> netsgiro.NETS_ID
    '00008080'

.. autoclass:: netsgiro.ServiceCode
    :members:
    :undoc-members:
    :member-order: bysource

.. autoclass:: netsgiro.RecordType
    :members:
    :undoc-members:
    :member-order: bysource

.. autoclass:: netsgiro.AssignmentType
    :members:
    :undoc-members:
    :member-order: bysource

.. autoclass:: netsgiro.TransactionType
    :members:
    :undoc-members:
    :member-order: bysource

.. autoclass:: netsgiro.AvtaleGiroRegistrationType
    :members:
    :undoc-members:
    :member-order: bysource
